###################
Gdstk Documentation
###################

Gdstk (GDSII Tool Kit) is a C++ library for creation and manipulation of GDSII
and OASIS files.  It is also available as a Python module meant to be a
successor to `Gdspy <https://github.com/heitzmann/gdspy>`_.

Key features for the creation of complex CAD layouts are included:

* Boolean operations on polygons (AND, OR, NOT, XOR) based on clipping
  algorithm

* Polygon offset (inward and outward rescaling of polygons)

* Efficient point-in-polygon solutions for large array sets

Typical applications of Gdstk are in the fields of electronic chip design,
planar lightwave circuit design, and mechanical engineering.

For installation instructions and other information, please check out the
`GitHub repository <https://github.com/heitzmann/gdstk>`_ or the README file
included with the source.

.. toctree::
   :maxdepth: 2
   :caption: Table of Contents

   gettingstarted
   how-tos
   reference_python
   reference_cpp


*******
Support
*******

Help support the development of Gdstk by donating:

.. image:: https://www.paypalobjects.com/en_US/i/btn/btn_donate_LG.gif
   :alt: PayPal
   :target: https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=JD2EUE2WPPBQQ
   :align: center


*******
License
*******

Boost Software License - Version 1.0 - August 17th, 2003

Permission is hereby granted, free of charge, to any person or organization
obtaining a copy of the software and accompanying documentation covered by
this license (the "Software") to use, reproduce, display, distribute,
execute, and transmit the Software, and to prepare derivative works of the
Software, and to permit third-parties to whom the Software is furnished to
do so, all subject to the following:

The copyright notices in the Software and this entire statement, including
the above license grant, this restriction and the following disclaimer,
must be included in all copies of the Software, in whole or in part, and
all derivative works of the Software, unless such copies or derivative
works are solely in the form of machine-executable object code generated by
a source language processor.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
